
import { useState } from 'react';
import CardList from './../components/CardList';
import { fetchUser } from '../services/apiGitHub.js';

const Home = () => {
  const [user, setUser] = useState({
    username: '',
  });

  const [profile, setProfile] = useState([]);

  const handleInputChange = (event) => {
    event.preventDefault();

    setUser({
      ...user,
      [event.target.name]: event.target.value,
    });
  }

  const fetchUserData = async () => {
    const data = await fetchUser(user.data);

    setProfile(data);
  };

  return (
    <main className='h-screen w-screen overflow-x-hidden bg-slate-200'>
      <header className="flex flex-wrap justify-center py-5 mb-4 border-b-2 border-solid border-[#252525]">
        <h2 className='font-serif text-2xl xl:text-4xl font-bold capitalize'>The GitHub Cards App</h2>
      </header>
      <div className='flex flex-col justify-center py-6 px-12 mx-auto'>
        <form action="" onSubmit={fetchUserData} className='flex flex-col mx-auto'>
          <div className="flex mb-4">
            <span className="inline-flex items-center px-3 text-sm text-gray-900 bg-gray-200 border rounded-e-0 border-gray-300 border-e-0 rounded-s-md dark:bg-gray-600 dark:text-gray-400 dark:border-gray-600">
              <svg className="w-4 h-4 text-gray-500 dark:text-gray-400" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
                  <path d="M10 0a10 10 0 1 0 10 10A10.011 10.011 0 0 0 10 0Zm0 5a3 3 0 1 1 0 6 3 3 0 0 1 0-6Zm0 13a8.949 8.949 0 0 1-4.951-1.488A3.987 3.987 0 0 1 9 13h2a3.987 3.987 0 0 1 3.951 3.512A8.949 8.949 0 0 1 10 18Z"/>
              </svg>
            </span>
            <input 
              value={user.username}
              onChange={handleInputChange}
              id="username" 
              required
              type="text"
              name='username'
              placeholder="Search for username"
              className="rounded-none rounded-e-lg bg-gray-50 border text-gray-900 focus:ring-blue-500 focus:border-blue-500 block flex-1 min-w-96 w-full text-sm border-gray-300 p-2.5"
             />
          </div>
          <button
           title='Button Submit'
           className="text-white bg-gradient-to-r from-blue-900 via-blue-600 to-blue-950 hover:bg-gradient-to-br focus:ring-4 focus:outline-none focus:ring-blue-300 dark:focus:ring-blue-800 shadow-lg shadow-blue-500/50 dark:shadow-lg dark:shadow-blue-800/80 font-medium rounded-lg text-sm px-5 py-2.5 text-center me-2 mb-2">
            Add to Card
          </button>
        </form>
      </div>
      <CardList profile={profile}/>
    </main>
  )
}

export default Home
